==> script-security-1.18-sources.jar: org/jenkinsci/plugins/scriptsecurity/scripts/languages/GroovyXmlLanguage.java <==
/*
 * The MIT License
 *
 * Copyright 2014 CloudBees, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package org.jenkinsci.plugins.scriptsecurity.scripts.languages;

import org.jenkinsci.plugins.scriptsecurity.scripts.Language;
import hudson.Extension;
import jenkins.model.Jenkins;

/**
 * Language for Groovy Template scripts generating XML.
 */
@Extension public final class GroovyXmlLanguage extends Language {

    public static Language get() {
        return Jenkins.getInstance().getExtensionList(Language.class).get(GroovyXmlLanguage.class);
    }

    @Override public String getName() {
        return "groovy-xml";
    }

    @Override public String getDisplayName() {
        return "Groovy Template for XML";
    }

    @Override public String getCodeMirrorMode() {
        return "xml"; // not exactly, but close enough?
    }

}

==> script-security-1.25-sources.jar: org/jenkinsci/plugins/scriptsecurity/scripts/languages/GroovyXmlLanguage.java <==
/*
 * The MIT License
 *
 * Copyright 2014 CloudBees, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package org.jenkinsci.plugins.scriptsecurity.scripts.languages;

import edu.umd.cs.findbugs.annotations.SuppressFBWarnings;
import org.jenkinsci.plugins.scriptsecurity.scripts.Language;
import hudson.Extension;
import jenkins.model.Jenkins;

/**
 * Language for Groovy Template scripts generating XML.
 */
@Extension public final class GroovyXmlLanguage extends Language {

    // TODO: To remove, use `getActiveInstance` 1.590+ and back to `getInstance` on 1.653+
    @SuppressFBWarnings(value = "NP_NULL_ON_SOME_PATH_FROM_RETURN_VALUE", justification = "https://github.com/jenkinsci/jenkins/pull/2094")
    public static Language get() {
        return Jenkins.getInstance().getExtensionList(Language.class).get(GroovyXmlLanguage.class);
    }

    @Override public String getName() {
        return "groovy-xml";
    }

    @Override public String getDisplayName() {
        return "Groovy Template for XML";
    }

    @Override public String getCodeMirrorMode() {
        return "xml"; // not exactly, but close enough?
    }

}
